Quoting

Enum Quoting 

pub enum Quoting {
    Auto,
    ExtraSafe,
}

Variants



Auto

Quote only arguments that need it for safety. This tries to be portable and safe across shells, but true safety and portability is hard to guarantee.



ExtraSafe

Quote all arguments, even ones that don’t need it. This is more likely to be safe under all circumstances.